@@ -190,7 +190,7 @@ brltty_brl_glib_cb (GIOChannel   *source,
 			client_callback (bec, &bed);
 		    break;
 		    default:
-			fprintf(stderr,_("BRLTTY command code not bound to Gnopernicus key code: 0X%04X\n)", keypress);
+			fprintf(stderr,_("BRLTTY command code not bound to Gnopernicus key code: 0X%04X\n"), keypress);
 		    break;
     		}
     	    break;
@@ -267,7 +267,7 @@ brltty_brl_open_device (gchar* 			device_name,
 	return 0;
     }
 
-    fprintf(stderr, _("BrlAPI detected a %dx%d display\n)", dd.x, dd.y);
+    fprintf(stderr, _("BrlAPI detected a %dx%d display\n"), dd.x, dd.y);
 
     device->cell_count = dd.x * dd.y;
     device->display_count = 1; /* No status cells implemented yet */
