@@ -530,6 +530,7 @@ gn_check_accessibility_key (void)
     GladeXML	*xml    = NULL;
     gint         response_id;
     gboolean     accessibility_on;
+    AtkObject *obj;
     
     /* check if accessibility flag is TRUE */
     accessibility_on = 	gnopiconf_get_bool (ACCESSIBILITY_GCONF_KEY, 
@@ -550,7 +551,7 @@ gn_check_accessibility_key (void)
     
     g_object_unref (G_OBJECT (xml));
     
-    AtkObject *obj = gtk_widget_get_accessible (dialog);
+    obj = gtk_widget_get_accessible (dialog);
     atk_object_set_role (obj, ATK_ROLE_ALERT);
     
     response_id = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -563,6 +564,8 @@ gn_check_accessibility_key (void)
 	
     if (response_id == GTK_RESPONSE_YES)
     {
+        AtkObject *obj;
+
 	gnopiconf_set_bool (TRUE, ACCESSIBILITY_GCONF_KEY);
 	
 	xml 	= gn_load_interface ("gnopi.glade2", "dl_logout");	
@@ -570,7 +573,7 @@ gn_check_accessibility_key (void)
 	
 	g_object_unref (G_OBJECT (xml));
 	
-        AtkObject *obj = gtk_widget_get_accessible (dialog);
+        obj = gtk_widget_get_accessible (dialog);
         atk_object_set_role (obj, ATK_ROLE_ALERT);
         
 	response_id = gtk_dialog_run (GTK_DIALOG (dialog));
