@@ -408,7 +408,7 @@ src_present_crt_window ()
 	    else if (strcmp (reason, "object:context-switched") == 0)
 	    {
 		context_switched = 0;
-	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
+	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_ERROR, TRUE);
 	    }
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
@@ -691,9 +691,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     }
     else if (strcmp (config->key, BRAILLE_PORT_NO) == 0)
     {
-    	sru_assert (config->newvalue && config->type == CFGT_INT);
-	
-	src_braille_set_port_no (*((gint*)config->newvalue));
+    	src_braille_set_port ();
+    }
+    else if (strcmp (config->key, BRAILLE_PORT) == 0)
+    {
+    	src_braille_set_port ();
     }
     else
 /*    if (config->key && strcmp (config->key, BRAILLE_ATTRIBUTES) == 0)
