@@ -661,6 +661,7 @@ src_speech_add_voice (gchar *voice)
 	src_voices->voices[i] = voices[i];
     src_voices->voices[i] = g_strdup (voice);
     src_voices->voices[i + 1] = NULL;
+    src_speech_get_voice_parameters_from_gconf (voice);
     g_free (voices);
 
     return TRUE;
@@ -1617,7 +1618,7 @@ src_speech_init ()
     {
     	sru_message (_("speech initialization succeded"));
 	if (src_speech_restored)
-	    src_speech_say_message (("Speech restored")); /*TO BE TRANSLATED*/
+	    src_speech_say_message (_("Speech restored"));
     }
     else
     {
